@@ -1,9 +1,10 @@
 require 'securerandom'
 
 class Gon
-  module GonHelpers
+  module ControllerHelpers
     private
 
+    # override this since ActionDispatch::Request#uuid appears only in Rails 3.2.1
     def gon_request_uuid
       @gon_request_uuid ||= SecureRandom.uuid
     end
