@@ -3,10 +3,7 @@ class Gon
     def include_gon(options = {})
       if variables_for_request_present?
         Gon::Base.render_data(options)
-      elsif Gon.global.all_variables.present?
-        Gon.clear
-        Gon::Base.render_data(options)
-      elsif options[:init].present?
+      elsif Gon.global.all_variables.present? || options[:init].present?
         Gon.clear
         Gon::Base.render_data(options)
       else
@@ -15,7 +12,7 @@ class Gon
     end
 
     def include_gon_amd(options={})
-      Gon::Base.render_data_amd(options)
+      Gon::Base.render_data(options.merge({amd: true}))
     end
 
     private
@@ -32,7 +29,7 @@ class Gon
   module ControllerHelpers
     def gon
       if wrong_gon_request?
-        gon_request = Request.new(env)
+        gon_request = Request.new(request.env)
         gon_request.id = gon_request_uuid
         RequestStore.store[:gon] = gon_request
       end
@@ -55,5 +52,9 @@ class Gon
   end
 end
 
-ActionView::Base.send :include, Gon::ViewHelpers
-ActionController::Base.send :include, Gon::ControllerHelpers
+ActiveSupport.on_load :action_view do
+  ActionView::Base.send :include, Gon::ViewHelpers
+end
+ActiveSupport.on_load :action_controller do
+  ActionController::Base.send :include, Gon::ControllerHelpers
+end
