@@ -1,6 +1,6 @@
 class Gon
   class Request
-    attr_reader :env
+    attr_reader :env, :gon
     attr_accessor :id
 
     def initialize(environment)
@@ -8,10 +8,6 @@ class Gon
       @gon = {}
     end
 
-    def gon
-      @gon
-    end
-
     def clear
       @gon = {}
     end
