@@ -24,7 +24,7 @@ class Gon
   end
 end
 
-if defined?(ActionController::TestCase::Behavior)
+if ENV['RAILS_ENV'] == 'test' && defined?(ActionController::TestCase::Behavior)
   ActionController::TestCase::Behavior.send :include, Gon::SpecHelper::Rails
 end
 
